You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@pekko.apache.org by jr...@apache.org on 2023/02/28 15:02:49 UTC

[incubator-pekko-http] branch main updated: replace usages of akka.io in tests (#90)

This is an automated email from the ASF dual-hosted git repository.

jrudolph pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/incubator-pekko-http.git


The following commit(s) were added to refs/heads/main by this push:
     new 663891e51 replace usages of akka.io in tests (#90)
663891e51 is described below

commit 663891e51a47c7a05f488ad5213401065a43f0cb
Author: Johannes Rudolph <jo...@gmail.com>
AuthorDate: Tue Feb 28 16:02:38 2023 +0100

    replace usages of akka.io in tests (#90)
---
 .../http/javadsl/ClientSingleRequestExample.java   |  6 +-
 .../java/docs/http/javadsl/Http2ClientApp.java     | 10 ++--
 .../http/javadsl/HttpClientExampleDocTest.java     |  4 +-
 .../server/HeaderRequestValsExampleTest.java       |  6 +-
 .../server/HttpBasicAuthenticatorExample.java      |  8 +--
 .../javadsl/server/OAuth2AuthenticatorExample.java |  8 +--
 .../RespondWithDirectivesExamplesTest.java         | 10 ++--
 .../directives/RouteDirectivesExamplesTest.java    |  2 +-
 .../scala/docs/http/scaladsl/Http2ClientApp.scala  | 10 ++--
 .../scaladsl/HttpClientCollectingHeaders.scala     |  2 +-
 .../docs/http/scaladsl/HttpClientExampleSpec.scala | 14 ++---
 .../scaladsl/HttpClientOutgoingConnection.scala    |  2 +-
 .../http/scaladsl/HttpClientSingleRequest.scala    |  2 +-
 .../directives/CustomDirectivesExamplesSpec.scala  |  8 +--
 .../RespondWithDirectivesExamplesSpec.scala        |  6 +-
 .../engine/client/HttpsProxyGraphStageSpec.scala   |  2 +-
 .../impl/engine/parsing/HttpHeaderParserSpec.scala |  6 +-
 .../impl/engine/parsing/RequestParserSpec.scala    |  2 +-
 .../impl/engine/parsing/ResponseParserSpec.scala   |  4 +-
 .../engine/rendering/RequestRendererSpec.scala     |  4 +-
 .../http/impl/model/parser/HttpHeaderSpec.scala    | 22 +++----
 .../http/scaladsl/model/HttpMessageSpec.scala      |  2 +-
 .../settings/ConnectionPoolSettingsSpec.scala      | 20 +++----
 .../apache/pekko/http/javadsl/HttpAPIsTest.java    | 70 +++++++++++-----------
 .../server/directives/RouteDirectivesSpec.scala    |  8 +--
 .../impl/engine/http2/RequestParsingSpec.scala     |  2 +-
 26 files changed, 120 insertions(+), 120 deletions(-)

diff --git a/docs/src/test/java/docs/http/javadsl/ClientSingleRequestExample.java b/docs/src/test/java/docs/http/javadsl/ClientSingleRequestExample.java
index 9e04e9aae..bf840c558 100644
--- a/docs/src/test/java/docs/http/javadsl/ClientSingleRequestExample.java
+++ b/docs/src/test/java/docs/http/javadsl/ClientSingleRequestExample.java
@@ -35,7 +35,7 @@ public class ClientSingleRequestExample {
 
     final CompletionStage<HttpResponse> responseFuture =
       Http.get(system)
-        .singleRequest(HttpRequest.create("https://akka.io"));
+        .singleRequest(HttpRequest.create("https://pekko.apache.org"));
   }
 }
 //#single-request-example
@@ -43,10 +43,10 @@ public class ClientSingleRequestExample {
 class OtherRequestResponseExamples {
   public void request() {
     //#create-simple-request
-    HttpRequest.create("https://akka.io");
+    HttpRequest.create("https://pekko.apache.org");
 
     // with query params
-    HttpRequest.create("https://akka.io?foo=bar");
+    HttpRequest.create("https://pekko.apache.org?foo=bar");
     //#create-simple-request
     //#create-post-request
     HttpRequest.POST("https://userservice.example/users")
diff --git a/docs/src/test/java/docs/http/javadsl/Http2ClientApp.java b/docs/src/test/java/docs/http/javadsl/Http2ClientApp.java
index 246af82a5..318b88944 100644
--- a/docs/src/test/java/docs/http/javadsl/Http2ClientApp.java
+++ b/docs/src/test/java/docs/http/javadsl/Http2ClientApp.java
@@ -54,11 +54,11 @@ public class Http2ClientApp {
 
     // #response-future-association
     Function<HttpRequest, CompletionStage<HttpResponse>> dispatch =
-        singleRequest(system, Http.get(system).connectionTo("doc.akka.io").http2());
+        singleRequest(system, Http.get(system).connectionTo("pekko.apache.org").http2());
 
     dispatch.apply(
         HttpRequest.create(
-            "https://doc.akka.io/api/akka/current/akka/actor/typed/scaladsl/index.html").withHeaders(
+            "https://pekko.apache.org/api/akka/current/akka/actor/typed/scaladsl/index.html").withHeaders(
             Arrays.asList(AcceptEncoding.create(HttpEncodings.GZIP))
         )
     ).thenAccept(res -> {
@@ -68,16 +68,16 @@ public class Http2ClientApp {
     });
 
     // #response-future-association
-    dispatch.apply(HttpRequest.create("https://doc.akka.io/api/akka/current/index.js"))
+    dispatch.apply(HttpRequest.create("https://pekko.apache.org/api/akka/current/index.js"))
         .thenAccept(res -> {
           System.out.println("[2] Got index.js: " + res);
           res.entity().getDataBytes().runWith(Sink.ignore(), mat)
             .thenAccept(consumedRes -> System.out.println("Finished reading [2] " + res));
         });
-    dispatch.apply(HttpRequest.create("https://doc.akka.io/api/akka/current/lib/MaterialIcons-Regular.woff"))
+    dispatch.apply(HttpRequest.create("https://pekko.apache.org/api/akka/current/lib/MaterialIcons-Regular.woff"))
         .thenCompose(res -> res.toStrict(1000, system))
         .thenAccept(res -> System.out.println("[3] Got font: " + res));
-    dispatch.apply(HttpRequest.create("https://doc.akka.io/favicon.ico"))
+    dispatch.apply(HttpRequest.create("https://pekko.apache.org/favicon.ico"))
         .thenCompose(res -> res.toStrict(1000, system))
         .thenAccept(res -> System.out.println("[4] Got favicon: " + res));
   }
diff --git a/docs/src/test/java/docs/http/javadsl/HttpClientExampleDocTest.java b/docs/src/test/java/docs/http/javadsl/HttpClientExampleDocTest.java
index 4063864c0..2e6dc7ff2 100644
--- a/docs/src/test/java/docs/http/javadsl/HttpClientExampleDocTest.java
+++ b/docs/src/test/java/docs/http/javadsl/HttpClientExampleDocTest.java
@@ -195,7 +195,7 @@ public class HttpClientExampleDocTest {
     final ActorSystem system = ActorSystem.create();
 
     final Flow<HttpRequest, HttpResponse, CompletionStage<OutgoingConnection>> connectionFlow =
-            Http.get(system).connectionTo("akka.io").http();
+            Http.get(system).connectionTo("pekko.apache.org").http();
     final CompletionStage<HttpResponse> responseFuture =
             // This is actually a bad idea in general. Even if the `connectionFlow` was instantiated only once above,
             // a new connection is opened every single time, `runWith` is called. Materialization (the `runWith` call)
@@ -222,7 +222,7 @@ public class HttpClientExampleDocTest {
 
     final CompletionStage<HttpResponse> responseFuture =
       Http.get(system)
-          .singleRequest(HttpRequest.create("http://akka.io"));
+          .singleRequest(HttpRequest.create("http://pekko.apache.org"));
     //#single-request-example
     system.terminate();
   }
diff --git a/docs/src/test/java/docs/http/javadsl/server/HeaderRequestValsExampleTest.java b/docs/src/test/java/docs/http/javadsl/server/HeaderRequestValsExampleTest.java
index f015105f6..9ce144bcb 100644
--- a/docs/src/test/java/docs/http/javadsl/server/HeaderRequestValsExampleTest.java
+++ b/docs/src/test/java/docs/http/javadsl/server/HeaderRequestValsExampleTest.java
@@ -46,9 +46,9 @@ public class HeaderRequestValsExampleTest extends JUnitRouteTest {
     // tests:
     final HttpRequest request =
       HttpRequest
-        .GET("http://akka.io/")
-      .addHeader(Host.create("akka.io"));
-    testRoute(route).run(request).assertEntity("Host header was: akka.io");
+        .GET("http://pekko.apache.org/")
+      .addHeader(Host.create("pekko.apache.org"));
+    testRoute(route).run(request).assertEntity("Host header was: pekko.apache.org");
 
     //#by-class
   }
diff --git a/docs/src/test/java/docs/http/javadsl/server/HttpBasicAuthenticatorExample.java b/docs/src/test/java/docs/http/javadsl/server/HttpBasicAuthenticatorExample.java
index b0e5b1f46..25643ed1e 100644
--- a/docs/src/test/java/docs/http/javadsl/server/HttpBasicAuthenticatorExample.java
+++ b/docs/src/test/java/docs/http/javadsl/server/HttpBasicAuthenticatorExample.java
@@ -53,15 +53,15 @@ public class HttpBasicAuthenticatorExample extends JUnitRouteTest {
         // tests:
         final HttpRequest okRequest =
             HttpRequest
-                .GET("http://akka.io/")
-                .addHeader(Host.create("akka.io"))
+                .GET("http://pekko.apache.org/")
+                .addHeader(Host.create("pekko.apache.org"))
                 .addHeader(Authorization.basic("randal", "correcthorsebatterystaple"));
         testRoute(route).run(okRequest).assertEntity("Hello randal!");
 
         final HttpRequest badRequest =
                 HttpRequest
-                        .GET("http://akka.io/")
-                        .addHeader(Host.create("akka.io"))
+                        .GET("http://pekko.apache.org/")
+                        .addHeader(Host.create("pekko.apache.org"))
                         .addHeader(Authorization.basic("randal", "123abc"));
         testRoute(route).run(badRequest).assertStatusCode(401);
 
diff --git a/docs/src/test/java/docs/http/javadsl/server/OAuth2AuthenticatorExample.java b/docs/src/test/java/docs/http/javadsl/server/OAuth2AuthenticatorExample.java
index 2447fa544..33ceec00f 100644
--- a/docs/src/test/java/docs/http/javadsl/server/OAuth2AuthenticatorExample.java
+++ b/docs/src/test/java/docs/http/javadsl/server/OAuth2AuthenticatorExample.java
@@ -58,15 +58,15 @@ public class OAuth2AuthenticatorExample extends JUnitRouteTest {
         // tests:
         final HttpRequest okRequest =
             HttpRequest
-                .GET("http://akka.io/")
-                .addHeader(Host.create("akka.io"))
+                .GET("http://pekko.apache.org/")
+                .addHeader(Host.create("pekko.apache.org"))
                 .addHeader(Authorization.oauth2("token"));
         testRoute(route).run(okRequest).assertEntity("The secret token is: token");
 
         final HttpRequest badRequest =
                 HttpRequest
-                        .GET("http://akka.io/")
-                        .addHeader(Host.create("akka.io"))
+                        .GET("http://pekko.apache.org/")
+                        .addHeader(Host.create("pekko.apache.org"))
                         .addHeader(Authorization.oauth2("wrong"));
         testRoute(route).run(badRequest).assertStatusCode(401);
 
diff --git a/docs/src/test/java/docs/http/javadsl/server/directives/RespondWithDirectivesExamplesTest.java b/docs/src/test/java/docs/http/javadsl/server/directives/RespondWithDirectivesExamplesTest.java
index 49ba3444e..591bdaaa4 100644
--- a/docs/src/test/java/docs/http/javadsl/server/directives/RespondWithDirectivesExamplesTest.java
+++ b/docs/src/test/java/docs/http/javadsl/server/directives/RespondWithDirectivesExamplesTest.java
@@ -63,7 +63,7 @@ public class RespondWithDirectivesExamplesTest extends JUnitRouteTest {
     public void testMultipleHeaders() {
         //#multiple-headers
         final List<HttpHeader> headers = Arrays.asList(
-                Origin.create(HttpOrigin.parse("http://akka.io")),
+                Origin.create(HttpOrigin.parse("http://pekko.apache.org")),
                 RawHeader.create("X-Fish-Name", "Blippy"));
         respondWithDefaultHeaders(headers, () ->
                 /*...*/
@@ -128,7 +128,7 @@ public class RespondWithDirectivesExamplesTest extends JUnitRouteTest {
     public void testRespondWithHeaders() {
         //#respondWithHeaders
         final HttpHeader gonzo = RawHeader.create("Funky-Muppet", "gonzo");
-        final HttpHeader akka = Origin.create(HttpOrigin.parse("http://akka.io"));
+        final HttpHeader akka = Origin.create(HttpOrigin.parse("http://pekko.apache.org"));
 
         final Route route = path("foo", () ->
                 respondWithHeaders(Arrays.asList(gonzo, akka), () ->
@@ -138,7 +138,7 @@ public class RespondWithDirectivesExamplesTest extends JUnitRouteTest {
 
         testRoute(route).run(HttpRequest.GET("/foo"))
                 .assertHeaderExists("Funky-Muppet", "gonzo")
-                .assertHeaderExists("Origin", "http://akka.io")
+                .assertHeaderExists("Origin", "http://pekko.apache.org")
                 .assertEntity("beep");
 
         //#respondWithHeaders
@@ -149,7 +149,7 @@ public class RespondWithDirectivesExamplesTest extends JUnitRouteTest {
         //#respondWithDefaultHeaders
         //custom headers
         final RawHeader blippy = RawHeader.create("X-Fish-Name", "Blippy");
-        final HttpHeader akka = Origin.create(HttpOrigin.parse("http://akka.io"));
+        final HttpHeader akka = Origin.create(HttpOrigin.parse("http://pekko.apache.org"));
         final List<HttpHeader> defaultHeaders = Arrays.asList(blippy, akka);
         final RawHeader elTonno = RawHeader.create("X-Fish-Name", "El Tonno");
 
@@ -174,7 +174,7 @@ public class RespondWithDirectivesExamplesTest extends JUnitRouteTest {
 
         testRoute(route).run(HttpRequest.GET("/"))
                 .assertHeaderExists("X-Fish-Name", "Blippy")
-                .assertHeaderExists("Origin", "http://akka.io")
+                .assertHeaderExists("Origin", "http://pekko.apache.org")
                 .assertEntity("Blip!");
 
         testRoute(route).run(HttpRequest.GET("/el-tonno"))
diff --git a/docs/src/test/java/docs/http/javadsl/server/directives/RouteDirectivesExamplesTest.java b/docs/src/test/java/docs/http/javadsl/server/directives/RouteDirectivesExamplesTest.java
index 4dc07ee8a..49b99b9ad 100644
--- a/docs/src/test/java/docs/http/javadsl/server/directives/RouteDirectivesExamplesTest.java
+++ b/docs/src/test/java/docs/http/javadsl/server/directives/RouteDirectivesExamplesTest.java
@@ -58,7 +58,7 @@ public class RouteDirectivesExamplesTest extends JUnitRouteTest {
   @Test
   public void testShowRedirectOnCompleteWithTerms() {
     final StatusCode redirectionType = StatusCodes.FOUND;
-    final Uri uri = Uri.create("http://akka.io");
+    final Uri uri = Uri.create("http://pekko.apache.org");
     final Function<RequestContext, CompletionStage<RouteResult>> route = rc ->
             //#red-impl
             rc.completeWith(HttpResponse.create()
diff --git a/docs/src/test/scala/docs/http/scaladsl/Http2ClientApp.scala b/docs/src/test/scala/docs/http/scaladsl/Http2ClientApp.scala
index 11d68f9cb..a71cbfe2e 100644
--- a/docs/src/test/scala/docs/http/scaladsl/Http2ClientApp.scala
+++ b/docs/src/test/scala/docs/http/scaladsl/Http2ClientApp.scala
@@ -46,11 +46,11 @@ object Http2ClientApp extends App {
   implicit val ec = system.dispatcher
 
   // #response-future-association
-  val dispatch = singleRequest(Http().connectionTo("doc.akka.io").http2())
+  val dispatch = singleRequest(Http().connectionTo("pekko.apache.org").http2())
 
   dispatch(
     HttpRequest(
-      uri = "https://doc.akka.io/api/akka/current/akka/actor/typed/scaladsl/index.html",
+      uri = "https://pekko.apache.org/api/akka/current/akka/actor/typed/scaladsl/index.html",
       headers = headers.`Accept-Encoding`(HttpEncodings.gzip) :: Nil)).onComplete { res =>
     println(s"[1] Got index.html: $res")
     res.get.entity.dataBytes.runWith(Sink.ignore).onComplete(res => println(s"Finished reading [1] $res"))
@@ -60,17 +60,17 @@ object Http2ClientApp extends App {
 
   dispatch(
     HttpRequest(
-      uri = "https://doc.akka.io/api/akka/current/index.js",
+      uri = "https://pekko.apache.org/api/akka/current/index.js",
       headers = /*headers.`Accept-Encoding`(HttpEncodings.gzip) ::*/ Nil)).onComplete { res =>
     println(s"[2] Got index.js: $res")
     res.get.entity.dataBytes.runWith(Sink.ignore).onComplete(res => println(s"Finished reading [2] $res"))
   }
 
-  dispatch(HttpRequest(uri = "https://doc.akka.io/api/akka/current/lib/MaterialIcons-Regular.woff"))
+  dispatch(HttpRequest(uri = "https://pekko.apache.org/api/akka/current/lib/MaterialIcons-Regular.woff"))
     .flatMap(_.toStrict(1.second))
     .onComplete(res => println(s"[3] Got font: $res"))
 
-  dispatch(HttpRequest(uri = "https://doc.akka.io/favicon.ico"))
+  dispatch(HttpRequest(uri = "https://pekko.apache.org/favicon.ico"))
     .flatMap(_.toStrict(1.second))
     .onComplete(res => println(s"[4] Got favicon: $res"))
 
diff --git a/docs/src/test/scala/docs/http/scaladsl/HttpClientCollectingHeaders.scala b/docs/src/test/scala/docs/http/scaladsl/HttpClientCollectingHeaders.scala
index f362a9536..ca6a33826 100644
--- a/docs/src/test/scala/docs/http/scaladsl/HttpClientCollectingHeaders.scala
+++ b/docs/src/test/scala/docs/http/scaladsl/HttpClientCollectingHeaders.scala
@@ -27,7 +27,7 @@ class HttpClientCollectingHeaders {
     implicit val system: ActorSystem = ActorSystem()
     implicit val executionContext: ExecutionContextExecutor = system.dispatcher
 
-    val responseFuture: Future[HttpResponse] = Http().singleRequest(HttpRequest(uri = "http://akka.io"))
+    val responseFuture: Future[HttpResponse] = Http().singleRequest(HttpRequest(uri = "http://pekko.apache.org"))
 
     responseFuture.map {
       case response @ HttpResponse(StatusCodes.OK, _, _, _) =>
diff --git a/docs/src/test/scala/docs/http/scaladsl/HttpClientExampleSpec.scala b/docs/src/test/scala/docs/http/scaladsl/HttpClientExampleSpec.scala
index 28ca3df2e..8a644456c 100644
--- a/docs/src/test/scala/docs/http/scaladsl/HttpClientExampleSpec.scala
+++ b/docs/src/test/scala/docs/http/scaladsl/HttpClientExampleSpec.scala
@@ -192,7 +192,7 @@ class HttpClientExampleSpec extends AnyWordSpec with Matchers with CompileOnlySp
 
     // This idea came initially from this blog post:
     // http://kazuhiro.github.io/scala/akka/akka-http/akka-streams/2016/01/31/connection-pooling-with-akka-http-and-source-queue.html
-    val poolClientFlow = Http().cachedHostConnectionPool[Promise[HttpResponse]]("akka.io")
+    val poolClientFlow = Http().cachedHostConnectionPool[Promise[HttpResponse]]("pekko.apache.org")
     val queue =
       Source.queue[(HttpRequest, Promise[HttpResponse])](QueueSize, OverflowStrategy.dropNew)
         .via(poolClientFlow)
@@ -247,7 +247,7 @@ class HttpClientExampleSpec extends AnyWordSpec with Matchers with CompileOnlySp
         FileToUpload("baz.txt", Paths.get("./baz.txt"))))
 
     val poolClientFlow =
-      Http().cachedHostConnectionPool[FileToUpload]("akka.io")
+      Http().cachedHostConnectionPool[FileToUpload]("pekko.apache.org")
 
     def createUploadRequest(fileToUpload: FileToUpload): Future[(HttpRequest, FileToUpload)] = {
       val bodyPart =
@@ -288,14 +288,14 @@ class HttpClientExampleSpec extends AnyWordSpec with Matchers with CompileOnlySp
     import pekko.actor.ActorSystem
     import pekko.http.scaladsl.model._
     // #create-simple-request
-    HttpRequest(uri = "https://akka.io")
+    HttpRequest(uri = "https://pekko.apache.org")
 
     // or:
     import org.apache.pekko.http.scaladsl.client.RequestBuilding.Get
-    Get("https://akka.io")
+    Get("https://pekko.apache.org")
 
     // with query params
-    Get("https://akka.io?foo=bar")
+    Get("https://pekko.apache.org?foo=bar")
 
     // #create-simple-request
 
@@ -344,7 +344,7 @@ class HttpClientExampleSpec extends AnyWordSpec with Matchers with CompileOnlySp
       val http = Http(system)
 
       override def preStart() = {
-        http.singleRequest(HttpRequest(uri = "http://akka.io"))
+        http.singleRequest(HttpRequest(uri = "http://pekko.apache.org"))
           .pipeTo(self)
       }
 
@@ -407,7 +407,7 @@ class HttpClientExampleSpec extends AnyWordSpec with Matchers with CompileOnlySp
     val settings = ConnectionPoolSettings(system)
       .withConnectionSettings(ClientConnectionSettings(system)
         .withTransport(httpsProxyTransport))
-    Http().singleRequest(HttpRequest(uri = "http://akka.io"), settings = settings)
+    Http().singleRequest(HttpRequest(uri = "http://pekko.apache.org"), settings = settings)
     // #auth-https-proxy-example-single-request
   }
 
diff --git a/docs/src/test/scala/docs/http/scaladsl/HttpClientOutgoingConnection.scala b/docs/src/test/scala/docs/http/scaladsl/HttpClientOutgoingConnection.scala
index b17670187..6b1cf4155 100644
--- a/docs/src/test/scala/docs/http/scaladsl/HttpClientOutgoingConnection.scala
+++ b/docs/src/test/scala/docs/http/scaladsl/HttpClientOutgoingConnection.scala
@@ -28,7 +28,7 @@ object HttpClientOutgoingConnection {
     implicit val executionContext = system.dispatcher
 
     val connectionFlow: Flow[HttpRequest, HttpResponse, Future[Http.OutgoingConnection]] =
-      Http().connectionTo("akka.io").http()
+      Http().connectionTo("pekko.apache.org").http()
 
     def dispatchRequest(request: HttpRequest): Future[HttpResponse] =
       // This is actually a bad idea in general. Even if the `connectionFlow` was instantiated only once above,
diff --git a/docs/src/test/scala/docs/http/scaladsl/HttpClientSingleRequest.scala b/docs/src/test/scala/docs/http/scaladsl/HttpClientSingleRequest.scala
index 57bc76c61..8caa92726 100644
--- a/docs/src/test/scala/docs/http/scaladsl/HttpClientSingleRequest.scala
+++ b/docs/src/test/scala/docs/http/scaladsl/HttpClientSingleRequest.scala
@@ -28,7 +28,7 @@ object HttpClientSingleRequest {
     // needed for the future flatMap/onComplete in the end
     implicit val executionContext = system.executionContext
 
-    val responseFuture: Future[HttpResponse] = Http().singleRequest(HttpRequest(uri = "http://akka.io"))
+    val responseFuture: Future[HttpResponse] = Http().singleRequest(HttpRequest(uri = "http://pekko.apache.org"))
 
     responseFuture
       .onComplete {
diff --git a/docs/src/test/scala/docs/http/scaladsl/server/directives/CustomDirectivesExamplesSpec.scala b/docs/src/test/scala/docs/http/scaladsl/server/directives/CustomDirectivesExamplesSpec.scala
index 1cb9e1e38..b1de5222b 100644
--- a/docs/src/test/scala/docs/http/scaladsl/server/directives/CustomDirectivesExamplesSpec.scala
+++ b/docs/src/test/scala/docs/http/scaladsl/server/directives/CustomDirectivesExamplesSpec.scala
@@ -123,9 +123,9 @@ class CustomDirectivesExamplesSpec extends RoutingSpec with CompileOnlySpec {
       (hostname, port) => complete(s"The hostname is $hostname and the port is $port")
     }
 
-    Get() ~> Host("akka.io", 8080) ~> route ~> check {
+    Get() ~> Host("pekko.apache.org", 8080) ~> route ~> check {
       status shouldEqual OK
-      responseAs[String] shouldEqual "The hostname is akka.io and the port is 8080"
+      responseAs[String] shouldEqual "The hostname is pekko.apache.org and the port is 8080"
     }
     // #scratch-1
   }
@@ -144,9 +144,9 @@ class CustomDirectivesExamplesSpec extends RoutingSpec with CompileOnlySpec {
       (hostname, port) => complete(s"The hostname is $hostname and the port is $port")
     }
 
-    Get() ~> Host("akka.io", 8080) ~> route ~> check {
+    Get() ~> Host("pekko.apache.org", 8080) ~> route ~> check {
       status shouldEqual OK
-      responseAs[String] shouldEqual "The hostname is akka.io and the port is 8080"
+      responseAs[String] shouldEqual "The hostname is pekko.apache.org and the port is 8080"
     }
     // #scratch-2
   }
diff --git a/docs/src/test/scala/docs/http/scaladsl/server/directives/RespondWithDirectivesExamplesSpec.scala b/docs/src/test/scala/docs/http/scaladsl/server/directives/RespondWithDirectivesExamplesSpec.scala
index 6e5a6a0c9..d1e321e42 100644
--- a/docs/src/test/scala/docs/http/scaladsl/server/directives/RespondWithDirectivesExamplesSpec.scala
+++ b/docs/src/test/scala/docs/http/scaladsl/server/directives/RespondWithDirectivesExamplesSpec.scala
@@ -23,7 +23,7 @@ class RespondWithDirectivesExamplesSpec extends RoutingSpec with CompileOnlySpec
   "multiple-headers" in {
     // #multiple-headers
     respondWithDefaultHeaders(
-      Origin(HttpOrigin("http://akka.io")),
+      Origin(HttpOrigin("http://pekko.apache.org")),
       RawHeader("X-Fish-Name", "Blippy")) { ??? }
     // #multiple-headers
   }
@@ -91,7 +91,7 @@ class RespondWithDirectivesExamplesSpec extends RoutingSpec with CompileOnlySpec
     // #respondWithHeaders-0
     val route =
       path("foo") {
-        respondWithHeaders(RawHeader("Funky-Muppet", "gonzo"), Origin(HttpOrigin("http://akka.io"))) {
+        respondWithHeaders(RawHeader("Funky-Muppet", "gonzo"), Origin(HttpOrigin("http://pekko.apache.org"))) {
           complete("beep")
         }
       }
@@ -99,7 +99,7 @@ class RespondWithDirectivesExamplesSpec extends RoutingSpec with CompileOnlySpec
     // tests:
     Get("/foo") ~> route ~> check {
       header("Funky-Muppet") shouldEqual Some(RawHeader("Funky-Muppet", "gonzo"))
-      header[Origin] shouldEqual Some(Origin(HttpOrigin("http://akka.io")))
+      header[Origin] shouldEqual Some(Origin(HttpOrigin("http://pekko.apache.org")))
       responseAs[String] shouldEqual "beep"
     }
     // #respondWithHeaders-0
diff --git a/http-core/src/test/scala/org/apache/pekko/http/impl/engine/client/HttpsProxyGraphStageSpec.scala b/http-core/src/test/scala/org/apache/pekko/http/impl/engine/client/HttpsProxyGraphStageSpec.scala
index e460dd75b..40bf8d5da 100644
--- a/http-core/src/test/scala/org/apache/pekko/http/impl/engine/client/HttpsProxyGraphStageSpec.scala
+++ b/http-core/src/test/scala/org/apache/pekko/http/impl/engine/client/HttpsProxyGraphStageSpec.scala
@@ -186,7 +186,7 @@ class HttpsProxyGraphStageSpec extends PekkoSpecWithMaterializer {
   trait Context {
     val clientSettings = ClientConnectionSettings(system)
 
-    val targetHostName = "akka.io"
+    val targetHostName = "pekko.apache.org"
     val targetPort = 443
     val basicProxyAuth: BasicHttpCredentials = BasicHttpCredentials("testUsername", "testPassword")
 
diff --git a/http-core/src/test/scala/org/apache/pekko/http/impl/engine/parsing/HttpHeaderParserSpec.scala b/http-core/src/test/scala/org/apache/pekko/http/impl/engine/parsing/HttpHeaderParserSpec.scala
index e4ba38953..0a8cd4ccd 100644
--- a/http-core/src/test/scala/org/apache/pekko/http/impl/engine/parsing/HttpHeaderParserSpec.scala
+++ b/http-core/src/test/scala/org/apache/pekko/http/impl/engine/parsing/HttpHeaderParserSpec.scala
@@ -147,12 +147,12 @@ abstract class HttpHeaderParserSpec(mode: String, newLine: String) extends Pekko
     }
 
     "parse and cache an X-Forwarded-For with a hostname in it as a RawHeader" in new TestSetup() {
-      parseAndCache(s"X-Forwarded-For: 1.2.3.4, akka.io${newLine}x")() shouldEqual RawHeader("x-forwarded-for",
-        "1.2.3.4, akka.io")
+      parseAndCache(s"X-Forwarded-For: 1.2.3.4, pekko.apache.org${newLine}x")() shouldEqual RawHeader("x-forwarded-for",
+        "1.2.3.4, pekko.apache.org")
     }
 
     "parse and cache an X-Real-Ip with a hostname as it's value as a RawHeader" in new TestSetup() {
-      parseAndCache(s"X-Real-Ip: akka.io${newLine}x")() shouldEqual RawHeader("x-real-ip", "akka.io")
+      parseAndCache(s"X-Real-Ip: pekko.apache.org${newLine}x")() shouldEqual RawHeader("x-real-ip", "pekko.apache.org")
     }
 
     "parse and cache a raw header" in new TestSetup(testSetupMode = TestSetupMode.Unprimed) {
diff --git a/http-core/src/test/scala/org/apache/pekko/http/impl/engine/parsing/RequestParserSpec.scala b/http-core/src/test/scala/org/apache/pekko/http/impl/engine/parsing/RequestParserSpec.scala
index 944ec93e5..722cc2ae8 100644
--- a/http-core/src/test/scala/org/apache/pekko/http/impl/engine/parsing/RequestParserSpec.scala
+++ b/http-core/src/test/scala/org/apache/pekko/http/impl/engine/parsing/RequestParserSpec.scala
@@ -592,7 +592,7 @@ abstract class RequestParserSpec(mode: String, newLine: String) extends AnyFreeS
       "two Host headers" in new Test {
         """GET / HTTP/1.1
           |Host: api.example.com
-          |Host: akka.io
+          |Host: pekko.apache.org
           |
           |foo""" should parseToError(
           BadRequest,
diff --git a/http-core/src/test/scala/org/apache/pekko/http/impl/engine/parsing/ResponseParserSpec.scala b/http-core/src/test/scala/org/apache/pekko/http/impl/engine/parsing/ResponseParserSpec.scala
index bebf7bb1d..c9b9ec810 100644
--- a/http-core/src/test/scala/org/apache/pekko/http/impl/engine/parsing/ResponseParserSpec.scala
+++ b/http-core/src/test/scala/org/apache/pekko/http/impl/engine/parsing/ResponseParserSpec.scala
@@ -124,9 +124,9 @@ abstract class ResponseParserSpec(mode: String, newLine: String) extends PekkoSp
       "a response with duplicate host headers" in new Test {
         """HTTP/1.0 404 Not Found
           |Host: api.example.com
-          |Host: akka.io
+          |Host: pekko.apache.org
           |
-          |Foobs""" should parseTo(HttpResponse(NotFound, List(Host("api.example.com"), Host("akka.io")),
+          |Foobs""" should parseTo(HttpResponse(NotFound, List(Host("api.example.com"), Host("pekko.apache.org")),
           "Foobs".getBytes, `HTTP/1.0`))
         closeAfterResponseCompletion shouldEqual Seq(true)
       }
diff --git a/http-core/src/test/scala/org/apache/pekko/http/impl/engine/rendering/RequestRendererSpec.scala b/http-core/src/test/scala/org/apache/pekko/http/impl/engine/rendering/RequestRendererSpec.scala
index 72243c8ab..4e095e584 100644
--- a/http-core/src/test/scala/org/apache/pekko/http/impl/engine/rendering/RequestRendererSpec.scala
+++ b/http-core/src/test/scala/org/apache/pekko/http/impl/engine/rendering/RequestRendererSpec.scala
@@ -81,11 +81,11 @@ class RequestRendererSpec extends AnyFreeSpec with Matchers with BeforeAndAfterA
         HttpRequest(POST, "/abc/xyz",
           List(
             RawHeader("X-Fancy", "naa"),
-            Link(Uri("http://akka.io"), LinkParams.first),
+            Link(Uri("http://pekko.apache.org"), LinkParams.first),
             Host("spray.io", 9999))) should renderTo {
           """POST /abc/xyz HTTP/1.1
             |X-Fancy: naa
-            |Link: <http://akka.io>; rel=first
+            |Link: <http://pekko.apache.org>; rel=first
             |Host: spray.io:9999
             |User-Agent: pekko-http/1.0.0
             |Content-Length: 0
diff --git a/http-core/src/test/scala/org/apache/pekko/http/impl/model/parser/HttpHeaderSpec.scala b/http-core/src/test/scala/org/apache/pekko/http/impl/model/parser/HttpHeaderSpec.scala
index 88adf2502..d7d973e52 100644
--- a/http-core/src/test/scala/org/apache/pekko/http/impl/model/parser/HttpHeaderSpec.scala
+++ b/http-core/src/test/scala/org/apache/pekko/http/impl/model/parser/HttpHeaderSpec.scala
@@ -89,8 +89,8 @@ class HttpHeaderSpec extends AnyFreeSpec with Matchers {
       "Access-Control-Allow-Origin: *" =!= `Access-Control-Allow-Origin`.`*`
       "Access-Control-Allow-Origin: null" =!= `Access-Control-Allow-Origin`.`null`
       "Access-Control-Allow-Origin: http://spray.io" =!= `Access-Control-Allow-Origin`("http://spray.io")
-      "Access-Control-Allow-Origin: http://akka.io http://spray.io" =!=
-        `Access-Control-Allow-Origin`.forRange(HttpOriginRange("http://akka.io", "http://spray.io"))
+      "Access-Control-Allow-Origin: http://pekko.apache.org http://spray.io" =!=
+        `Access-Control-Allow-Origin`.forRange(HttpOriginRange("http://pekko.apache.org", "http://spray.io"))
     }
 
     "Access-Control-Expose-Headers" in {
@@ -251,7 +251,7 @@ class HttpHeaderSpec extends AnyFreeSpec with Matchers {
     "Content-Location" in {
       "Content-Location: https://spray.io/secure" =!= `Content-Location`(Uri("https://spray.io/secure"))
       "Content-Location: /en-us/default.aspx?foo=bar" =!= `Content-Location`(Uri("/en-us/default.aspx?foo=bar"))
-      "Content-Location: https://akka.io/#sec" =!= ErrorInfo(
+      "Content-Location: https://pekko.apache.org/#sec" =!= ErrorInfo(
         "Illegal HTTP header 'Content-Location': requirement failed",
         "Content-Location header URI must not contain a fragment")
     }
@@ -484,7 +484,7 @@ class HttpHeaderSpec extends AnyFreeSpec with Matchers {
     "Referer" in {
       "Referer: https://spray.io/secure" =!= Referer(Uri("https://spray.io/secure"))
       "Referer: /en-us/default.aspx?foo=bar" =!= Referer(Uri("/en-us/default.aspx?foo=bar"))
-      "Referer: https://akka.io/#sec" =!= ErrorInfo(
+      "Referer: https://pekko.apache.org/#sec" =!= ErrorInfo(
         "Illegal HTTP header 'Referer': requirement failed",
         "Referer header URI must not contain a fragment")
     }
@@ -757,10 +757,10 @@ class HttpHeaderSpec extends AnyFreeSpec with Matchers {
       "X-Forwarded-For: 1:2:3:4:5::7:8" =!=> "1:2:3:4:5:0:7:8"
       "X-Forwarded-For: 1:2:3:4:5:6::8" =!=> "1:2:3:4:5:6:0:8"
       "X-Forwarded-For: ::" =!=> "0:0:0:0:0:0:0:0"
-      "X-Forwarded-For: 1.2.3.4, akka.io" =!=
+      "X-Forwarded-For: 1.2.3.4, pekko.apache.org" =!=
         ErrorInfo(
-          "Illegal HTTP header 'X-Forwarded-For': Invalid input 'k', expected HEXDIG, h8, ':', cc or ch16o (line 1, column 11)",
-          "1.2.3.4, akka.io\n          ^")
+          "Illegal HTTP header 'X-Forwarded-For': Invalid input 'p', expected WSP, CRLF or addr (line 1, column 10)",
+          "1.2.3.4, pekko.apache.org\n         ^")
     }
 
     "X-Forwarded-Host" in {
@@ -770,7 +770,7 @@ class HttpHeaderSpec extends AnyFreeSpec with Matchers {
         Uri.Host("1234:5678:9abc:def1:2345:6789:abcd:ef00"))
       "X-Forwarded-Host: [1234:567:9a:d:2:67:abc:ef00]" =!= `X-Forwarded-Host`(Uri.Host("1234:567:9a:d:2:67:abc:ef00"))
       "X-Forwarded-Host: [1:2:3:4:5:6:7:8]" =!= `X-Forwarded-Host`(Uri.Host("1:2:3:4:5:6:7:8"))
-      "X-Forwarded-Host: akka.io" =!= `X-Forwarded-Host`(Uri.Host("akka.io"))
+      "X-Forwarded-Host: pekko.apache.org" =!= `X-Forwarded-Host`(Uri.Host("pekko.apache.org"))
       "X-Forwarded-Host: [1:2:3:4::6:7:8]" =!= `X-Forwarded-Host`(Uri.Host("1:2:3:4::6:7:8"))
     }
 
@@ -811,10 +811,10 @@ class HttpHeaderSpec extends AnyFreeSpec with Matchers {
       "X-Real-Ip: 1:2:3:4:5::7:8" =!=> "1:2:3:4:5:0:7:8"
       "X-Real-Ip: 1:2:3:4:5:6::8" =!=> "1:2:3:4:5:6:0:8"
       "X-Real-Ip: ::" =!=> "0:0:0:0:0:0:0:0"
-      "X-Real-Ip: akka.io" =!=
+      "X-Real-Ip: pekko.apache.org" =!=
         ErrorInfo(
-          "Illegal HTTP header 'X-Real-Ip': Invalid input 'k', expected HEXDIG, h8, ':', cc or ch16o (line 1, column 2)",
-          "akka.io\n ^")
+          "Illegal HTTP header 'X-Real-Ip': Invalid input 'p', expected ip-v4-address or ip-v6-address (line 1, column 1)",
+          "pekko.apache.org\n^")
     }
 
     "RawHeader" in {
diff --git a/http-core/src/test/scala/org/apache/pekko/http/scaladsl/model/HttpMessageSpec.scala b/http-core/src/test/scala/org/apache/pekko/http/scaladsl/model/HttpMessageSpec.scala
index 4a115c05b..96e0f406b 100644
--- a/http-core/src/test/scala/org/apache/pekko/http/scaladsl/model/HttpMessageSpec.scala
+++ b/http-core/src/test/scala/org/apache/pekko/http/scaladsl/model/HttpMessageSpec.scala
@@ -100,7 +100,7 @@ class HttpMessageSpec extends AnyWordSpec with Matchers {
     "retrieve all headers of a given class when calling headers[...]" in {
       val oneCookieHeader = `Set-Cookie`(HttpCookie("foo", "bar"))
       val anotherCookieHeader = `Set-Cookie`(HttpCookie("foz", "baz"))
-      val hostHeader = Host("akka.io")
+      val hostHeader = Host("pekko.apache.org")
       val request = HttpRequest().withHeaders(oneCookieHeader, anotherCookieHeader, hostHeader)
       request.headers[`Set-Cookie`] should ===(Seq(oneCookieHeader, anotherCookieHeader))
     }
diff --git a/http-tests/src/test/java/org/apache/pekko/http/javadsl/HttpAPIsTest.java b/http-tests/src/test/java/org/apache/pekko/http/javadsl/HttpAPIsTest.java
index 0553b9762..5d9b2e761 100644
--- a/http-tests/src/test/java/org/apache/pekko/http/javadsl/HttpAPIsTest.java
+++ b/http-tests/src/test/java/org/apache/pekko/http/javadsl/HttpAPIsTest.java
@@ -71,25 +71,25 @@ public class HttpAPIsTest extends JUnitRouteTest {
     http.singleRequest(handler3, httpsContext);
     http.singleRequest(handler3, httpsContext, conSettings, log);
 
-    http.outgoingConnection("akka.io");
-    http.outgoingConnection("akka.io:8080");
-    http.outgoingConnection("https://akka.io");
-    http.outgoingConnection("https://akka.io:8081");
-
-    http.outgoingConnection(toHost("akka.io"));
-    http.outgoingConnection(toHost("akka.io", 8080));
-    http.outgoingConnection(toHost("https://akka.io"));
-    http.outgoingConnection(toHostHttps("akka.io")); // default ssl context (ssl-config)
-    http.outgoingConnection(toHostHttps("ssh://akka.io")); // throws, we explicitly require https or ""
-    http.outgoingConnection(toHostHttps("akka.io", 8081).withCustomHttpsContext(httpsContext));
-    http.outgoingConnection(toHostHttps("akka.io", 8081).withCustomHttpsContext(httpsContext).withDefaultHttpsContext());
-    http.outgoingConnection(toHostHttps("akka.io", 8081).withCustomHttpsContext(httpsContext).withDefaultHttpsContext());
-
-    http.connectionTo("akka.io").http();
-    http.connectionTo("akka.io").https();
-    http.connectionTo("akka.io").http2();
-    http.connectionTo("akka.io").http2WithPriorKnowledge();
-    http.connectionTo("akka.io")
+    http.outgoingConnection("pekko.apache.org");
+    http.outgoingConnection("pekko.apache.org:8080");
+    http.outgoingConnection("https://pekko.apache.org");
+    http.outgoingConnection("https://pekko.apache.org:8081");
+
+    http.outgoingConnection(toHost("pekko.apache.org"));
+    http.outgoingConnection(toHost("pekko.apache.org", 8080));
+    http.outgoingConnection(toHost("https://pekko.apache.org"));
+    http.outgoingConnection(toHostHttps("pekko.apache.org")); // default ssl context (ssl-config)
+    http.outgoingConnection(toHostHttps("ssh://pekko.apache.org")); // throws, we explicitly require https or ""
+    http.outgoingConnection(toHostHttps("pekko.apache.org", 8081).withCustomHttpsContext(httpsContext));
+    http.outgoingConnection(toHostHttps("pekko.apache.org", 8081).withCustomHttpsContext(httpsContext).withDefaultHttpsContext());
+    http.outgoingConnection(toHostHttps("pekko.apache.org", 8081).withCustomHttpsContext(httpsContext).withDefaultHttpsContext());
+
+    http.connectionTo("pekko.apache.org").http();
+    http.connectionTo("pekko.apache.org").https();
+    http.connectionTo("pekko.apache.org").http2();
+    http.connectionTo("pekko.apache.org").http2WithPriorKnowledge();
+    http.connectionTo("pekko.apache.org")
         .toPort(8081)
         .withCustomHttpsConnectionContext(httpsContext)
         .withClientConnectionSettings(ClientConnectionSettings.create(ConfigFactory.empty()))
@@ -98,30 +98,30 @@ public class HttpAPIsTest extends JUnitRouteTest {
 
     // in future we can add modify(context -> Context) to "keep ssl-config defaults, but tweak them in code)
 
-    http.newHostConnectionPool("akka.io", materializer());
-    http.newHostConnectionPool("https://akka.io", materializer());
-    http.newHostConnectionPool("https://akka.io:8080", materializer());
-    http.newHostConnectionPool(toHost("akka.io"), materializer());
-    http.newHostConnectionPool(toHostHttps("ftp://akka.io"), materializer()); // throws, we explicitly require https or ""
-    http.newHostConnectionPool(toHostHttps("https://akka.io:2222"), materializer());
-    http.newHostConnectionPool(toHostHttps("akka.io"), materializer());
+    http.newHostConnectionPool("pekko.apache.org", materializer());
+    http.newHostConnectionPool("https://pekko.apache.org", materializer());
+    http.newHostConnectionPool("https://pekko.apache.org:8080", materializer());
+    http.newHostConnectionPool(toHost("pekko.apache.org"), materializer());
+    http.newHostConnectionPool(toHostHttps("ftp://pekko.apache.org"), materializer()); // throws, we explicitly require https or ""
+    http.newHostConnectionPool(toHostHttps("https://pekko.apache.org:2222"), materializer());
+    http.newHostConnectionPool(toHostHttps("pekko.apache.org"), materializer());
     http.newHostConnectionPool(toHost(""), conSettings, log, materializer());
 
 
-    http.cachedHostConnectionPool("akka.io");
-    http.cachedHostConnectionPool("https://akka.io");
-    http.cachedHostConnectionPool("https://akka.io:8080");
-    http.cachedHostConnectionPool(toHost("akka.io"));
-    http.cachedHostConnectionPool(toHostHttps("smtp://akka.io")); // throws, we explicitly require https or ""
-    http.cachedHostConnectionPool(toHostHttps("https://akka.io:2222"));
-    http.cachedHostConnectionPool(toHostHttps("akka.io"));
-    http.cachedHostConnectionPool(toHost("akka.io"), conSettings, log);
+    http.cachedHostConnectionPool("pekko.apache.org");
+    http.cachedHostConnectionPool("https://pekko.apache.org");
+    http.cachedHostConnectionPool("https://pekko.apache.org:8080");
+    http.cachedHostConnectionPool(toHost("pekko.apache.org"));
+    http.cachedHostConnectionPool(toHostHttps("smtp://pekko.apache.org")); // throws, we explicitly require https or ""
+    http.cachedHostConnectionPool(toHostHttps("https://pekko.apache.org:2222"));
+    http.cachedHostConnectionPool(toHostHttps("pekko.apache.org"));
+    http.cachedHostConnectionPool(toHost("pekko.apache.org"), conSettings, log);
 
     http.superPool();
     http.superPool(conSettings, log);
     http.superPool(conSettings, httpsContext, log);
 
-    final ConnectWithHttps connect = toHostHttps("akka.io", 8081).withCustomHttpsContext(httpsContext).withDefaultHttpsContext();
+    final ConnectWithHttps connect = toHostHttps("pekko.apache.org", 8081).withCustomHttpsContext(httpsContext).withDefaultHttpsContext();
     connect.effectiveHttpsConnectionContext(http.defaultClientHttpsContext()); // usage by us internally
   }
 
diff --git a/http-tests/src/test/scala/org/apache/pekko/http/scaladsl/server/directives/RouteDirectivesSpec.scala b/http-tests/src/test/scala/org/apache/pekko/http/scaladsl/server/directives/RouteDirectivesSpec.scala
index 7f68e75ab..5e17e7dc3 100644
--- a/http-tests/src/test/scala/org/apache/pekko/http/scaladsl/server/directives/RouteDirectivesSpec.scala
+++ b/http-tests/src/test/scala/org/apache/pekko/http/scaladsl/server/directives/RouteDirectivesSpec.scala
@@ -184,19 +184,19 @@ class RouteDirectivesSpec extends AnyWordSpec with GenericRoutingSpec {
 
   "the handle directive" should {
     "use a function to complete a request" in {
-      Get(Uri("https://akka.io/foo")) ~> {
+      Get(Uri("https://pekko.apache.org/foo")) ~> {
         handle(req => Future.successful(HttpResponse(OK, entity = req.uri.toString)))
-      } ~> check { response shouldEqual HttpResponse(200, entity = "https://akka.io/foo") }
+      } ~> check { response shouldEqual HttpResponse(200, entity = "https://pekko.apache.org/foo") }
     }
     "fail the request when the future fails" in {
-      Get(Uri("https://akka.io/foo")) ~> {
+      Get(Uri("https://pekko.apache.org/foo")) ~> {
         concat(
           handle(req => Future.failed(new IllegalStateException("Some error"))),
           complete(ImATeapot))
       } ~> check { response shouldEqual HttpResponse(500, entity = "There was an internal server error.") }
     }
     "fail the request when the function throws" in {
-      Get(Uri("https://akka.io/foo")) ~> {
+      Get(Uri("https://pekko.apache.org/foo")) ~> {
         concat(
           handle(req => throw new IllegalStateException("Some error")),
           complete(ImATeapot))
diff --git a/http2-tests/src/test/scala/org/apache/pekko/http/impl/engine/http2/RequestParsingSpec.scala b/http2-tests/src/test/scala/org/apache/pekko/http/impl/engine/http2/RequestParsingSpec.scala
index d51390828..44b37db10 100644
--- a/http2-tests/src/test/scala/org/apache/pekko/http/impl/engine/http2/RequestParsingSpec.scala
+++ b/http2-tests/src/test/scala/org/apache/pekko/http/impl/engine/http2/RequestParsingSpec.scala
@@ -453,7 +453,7 @@ class RequestParsingSpec extends PekkoSpecWithMaterializer with Inside with Insp
               keyValuePairs = Vector(
                 ":scheme" -> "https",
                 ":method" -> "GET",
-                ":authority" -> "akka.io",
+                ":authority" -> "pekko.apache.org",
                 ":path" -> "/") :+ (name -> alternative)))
             thrown.getMessage should ===(s"Malformed request: Pseudo-header '$name' must not occur more than once")
         }


---------------------------------------------------------------------
To unsubscribe, e-mail: commits-unsubscribe@pekko.apache.org
For additional commands, e-mail: commits-help@pekko.apache.org
diff --git a/http-core/src/test/scala/org/apache/pekko/http/scaladsl/settings/ConnectionPoolSettingsSpec.scala b/http-core/src/test/scala/org/apache/pekko/http/scaladsl/settings/ConnectionPoolSettingsSpec.scala
index adedcccda..d86582652 100644
--- a/http-core/src/test/scala/org/apache/pekko/http/scaladsl/settings/ConnectionPoolSettingsSpec.scala
+++ b/http-core/src/test/scala/org/apache/pekko/http/scaladsl/settings/ConnectionPoolSettingsSpec.scala
@@ -59,7 +59,7 @@ class ConnectionPoolSettingsSpec extends PekkoSpec {
           |
           |  per-host-override : [
           |    {
-          |      host-pattern = "akka.io"
+          |      host-pattern = "pekko.apache.org"
           |      # can use same things as in global `host-connection-pool` section
           |      max-connections = 47
           |    },
@@ -84,8 +84,8 @@ class ConnectionPoolSettingsSpec extends PekkoSpec {
         ConfigFactory.parseString(settingsString)
           .withFallback(ConfigFactory.defaultReference(getClass.getClassLoader)))
 
-      settings.forHost("akka.io").maxConnections shouldEqual 47
-      settings.forHost("test.akka.io").maxConnections shouldEqual 7
+      settings.forHost("pekko.apache.org").maxConnections shouldEqual 47
+      settings.forHost("test.pekko.apache.org").maxConnections shouldEqual 7
       settings.forHost("example.com").maxConnections shouldEqual 34
       settings.forHost("www.example.com").maxConnections shouldEqual 34
       settings.forHost("example2.com").maxConnections shouldEqual 39
@@ -107,7 +107,7 @@ class ConnectionPoolSettingsSpec extends PekkoSpec {
           |
           |  per-host-override = [
           |    {
-          |      host-pattern = "akka.io"
+          |      host-pattern = "pekko.apache.org"
           |      # can use same things as in global `host-connection-pool` section
           |      max-connections = 47
           |    }
@@ -117,11 +117,11 @@ class ConnectionPoolSettingsSpec extends PekkoSpec {
 
       val settings = ConnectionPoolSettings(
         ConfigFactory.parseString(settingsString).withFallback(ConfigFactory.defaultReference(getClass.getClassLoader)))
-      settings.forHost("akka.io").maxConnections shouldEqual 47
+      settings.forHost("pekko.apache.org").maxConnections shouldEqual 47
       settings.maxConnections shouldEqual 7
 
       val settingsWithCodeOverrides = settings.withMaxConnections(42)
-      settingsWithCodeOverrides.forHost("akka.io").maxConnections shouldEqual 42
+      settingsWithCodeOverrides.forHost("pekko.apache.org").maxConnections shouldEqual 42
       settingsWithCodeOverrides.maxConnections shouldEqual 42
     }
 
@@ -134,7 +134,7 @@ class ConnectionPoolSettingsSpec extends PekkoSpec {
           |
           |  per-host-override = [
           |    {
-          |      host-pattern = "akka.io"
+          |      host-pattern = "pekko.apache.org"
           |      # can use same things as in global `host-connection-pool` section
           |      max-connections = 27
           |    },
@@ -150,13 +150,13 @@ class ConnectionPoolSettingsSpec extends PekkoSpec {
 
       val settings = ConnectionPoolSettings(
         ConfigFactory.parseString(settingsString).withFallback(ConfigFactory.defaultReference(getClass.getClassLoader)))
-      settings.forHost("akka.io").maxConnections shouldEqual 27
+      settings.forHost("pekko.apache.org").maxConnections shouldEqual 27
       settings.forHost("other.io").maxConnections shouldEqual 47
       settings.forHost("akka.com").maxConnections shouldEqual 7
       settings.maxConnections shouldEqual 7
 
-      // the '*.io' overrides are not selected, because akka.io occurs earlier:
-      settings.forHost("akka.io").minConnections shouldEqual 2
+      // the '*.io' overrides are not selected, because pekko.apache.org occurs earlier:
+      settings.forHost("pekko.apache.org").minConnections shouldEqual 2
       settings.forHost("other.io").minConnections shouldEqual 22
       settings.forHost("akka.com").minConnections shouldEqual 2
       settings.minConnections shouldEqual 2